==> jasperreports-server-cp-4.0.0-src.zip: jasperreports-server-cp-4.0.0-src/jasperserver/jasperserver-api-impl/engine/src/main/java/com/jaspersoft/jasperserver/api/engine/jasperreports/service/impl/JndiJdbcDataSourceService.java <==
/*
 * Copyright (C) 2005 - 2011 Jaspersoft Corporation. All rights reserved.
 * http://www.jaspersoft.com.
 *
 * Unless you have purchased  a commercial license agreement from Jaspersoft,
 * the following license terms  apply:
 *
 * This program is free software: you can redistribute it and/or  modify
 * it under the terms of the GNU Affero General Public License  as
 * published by the Free Software Foundation, either version 3 of  the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero  General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public  License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package com.jaspersoft.jasperserver.api.engine.jasperreports.service.impl;

import java.sql.Connection;
import java.sql.SQLException;

import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.sql.DataSource;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.jaspersoft.jasperserver.api.JSExceptionWrapper;


/**
 * @author Lucian Chirita (lucianc@users.sourceforge.net)
 * @version $Id: JndiJdbcDataSourceService.java 19922 2010-12-11 14:59:51Z tmatyashovsky $
 */
public class JndiJdbcDataSourceService extends BaseJdbcDataSource {
	
	private static final Log log = LogFactory.getLog(JndiJdbcDataSourceService.class);

	private final String jndiName;
	
	public JndiJdbcDataSourceService(String jndiName) {
		this.jndiName = jndiName;
	}
	
	protected Connection createConnection() {
		try
		{
			Context ctx = new InitialContext();
			DataSource ds = (DataSource) ctx.lookup("java:comp/env/" + jndiName);
			return ds.getConnection();
		}
		catch (NamingException e)
		{
			if (log.isDebugEnabled())
				log.debug(e, e);
			throw new JSExceptionWrapper(e);
		}
		catch (SQLException e)
		{
			if (log.isDebugEnabled())
				log.debug(e, e);
			throw new JSExceptionWrapper(e);
		}
	}

}

==> jasperreports-server-cp-4.2.1-src.zip: jasperreports-server-cp-4.2.1-src/jasperserver/jasperserver-api-impl/engine/src/main/java/com/jaspersoft/jasperserver/api/engine/jasperreports/service/impl/JndiJdbcDataSourceService.java <==
/*
 * Copyright (C) 2005 - 2011 Jaspersoft Corporation. All rights reserved.
 * http://www.jaspersoft.com.
 *
 * Unless you have purchased  a commercial license agreement from Jaspersoft,
 * the following license terms  apply:
 *
 * This program is free software: you can redistribute it and/or  modify
 * it under the terms of the GNU Affero General Public License  as
 * published by the Free Software Foundation, either version 3 of  the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero  General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public  License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package com.jaspersoft.jasperserver.api.engine.jasperreports.service.impl;

import java.sql.Connection;
import java.sql.SQLException;

import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.sql.DataSource;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.jaspersoft.jasperserver.api.JSExceptionWrapper;


/**
 * @author Lucian Chirita (lucianc@users.sourceforge.net)
 * @version $Id: JndiJdbcDataSourceService.java 20205 2011-02-25 20:30:39Z tchow $
 */
public class JndiJdbcDataSourceService extends BaseJdbcDataSource {
	
	private static final Log log = LogFactory.getLog(JndiJdbcDataSourceService.class);

	private final String jndiName;
	
	public JndiJdbcDataSourceService(String jndiName) {
		this.jndiName = jndiName;
	}
	
	protected Connection createConnection() {
		try
		{
			Context ctx = new InitialContext();
			DataSource ds = (DataSource) ctx.lookup("java:comp/env/" + jndiName);
      Connection c = ds.getConnection();
      if (log.isDebugEnabled()) {
        log.debug("CreateConnection successful at com.jaspersoft.jasperserver.api.engine.jasperreports.service.impl.JndiJdbcDataSourceService.createConnection");
      }
			return c;
		}
		catch (NamingException e)
		{
			if (log.isDebugEnabled())
				log.debug(e, e);
			throw new JSExceptionWrapper(e);
		}
		catch (SQLException e)
		{
			if (log.isDebugEnabled())
				log.debug(e, e);
			throw new JSExceptionWrapper(e);
		}
	}

}
